/*
 * ################################################################
 *
 * ProActive Parallel Suite(TM): The Java(TM) library for
 *    Parallel, Distributed, Multi-Core Computing for
 *    Enterprise Grids & Clouds
 *
 * Copyright (C) 1997-2011 INRIA/University of
 *                 Nice-Sophia Antipolis/ActiveEon
 * Contact: proactive@ow2.org or contact@activeeon.com
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; version 3 of
 * the License.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * If needed, contact us to obtain a release under GPL Version 2 or 3
 * or a different license than the AGPL.
 *
 *  Initial developer(s):               The ProActive Team
 *                        http://proactive.inria.fr/team_members.htm
 *  Contributor(s):
 *
 * ################################################################
 * $$PROACTIVE_INITIAL_DEV$$
 */
package org.ow2.proactive.db;

/**
 * Comparator for the Scheduler Database Condition.
 * Used inside a request to compare two objects.
 *
 * @author The ProActive Team
 * @since ProActive Scheduling 0.9.1
 */
public enum ConditionComparator {

    /** Used to compare (<) two comparable types : Integer, Long, float, ... */
    LESS_THAN("<"),
    /** Used to compare (<=) two comparable types : Integer, Long, float, ... */
    LESS_EQUALS_THAN("<="),
    /** Used to compare (=)everything */
    EQUALS_TO("="),
    /** Used to compare (>=) two comparable types : Integer, Long, float, ... */
    GREATER_THAN(">="),
    /** Used to compare (>) two comparable types : Integer, Long, float, ... */
    GREATER(">");

    /** symbol to be used in the request. */
    private String symbol;

    /**
     * Create a new instance of ConditionComparator.
     *
     * @param sign the symbol to use in the request as a String
     */
    private ConditionComparator(String symbol) {
        this.symbol = symbol;
    }

    /**
     * Get the symbol corresponding to this enum.
     *
     * @return the symbol corresponding to this enum.
     */
    public String getSymbol() {
        return symbol;
    }

}
